@@ -1,4 +1,4 @@
-# Copyright 2011-2017, Damian Johnson and The Tor Project
+# Copyright 2011-2018, Damian Johnson and The Tor Project
 # See LICENSE for licensing information
 
 """
@@ -8,14 +8,23 @@ Library for working with the tor process.
 
 ::
 
+  Endpoint - Networking endpoint.
+    |- ORPort - Tor relay endpoint.
+    +- DirPort - Descriptor mirror.
+
   ControllerError - Base exception raised when using the controller.
     |- ProtocolError - Malformed socket data.
+    |
     |- OperationFailed - Tor was unable to successfully complete the operation.
     |  |- UnsatisfiableRequest - Tor was unable to satisfy a valid request.
-    |  |  +- CircuitExtensionFailed - Attempt to make or extend a circuit failed.
-    |  |- DescriptorUnavailable - The given relay descriptor is unavailable.
+    |  |  |- CircuitExtensionFailed - Attempt to make or extend a circuit failed.
+    |  |  |- DescriptorUnavailable - The given relay descriptor is unavailable.
+    |  |  +- Timeout - Caller requested timeout was reached.
+    |  |
+    |  |
     |  +- InvalidRequest - Invalid request.
     |     +- InvalidArguments - Invalid request parameters.
+    |
     +- SocketError - Communication with the socket failed.
        +- SocketClosed - Socket has been shut down.
 
@@ -476,20 +485,23 @@ Library for working with the tor process.
   ================= ===========
 """
 
+import stem.util
 import stem.util.enum
 
-__version__ = '1.6.0'
+__version__ = '1.7.0'
 __author__ = 'Damian Johnson'
 __contact__ = 'atagar@torproject.org'
 __url__ = 'https://stem.torproject.org/'
 __license__ = 'LGPLv3'
 
 __all__ = [
+  'client',
   'descriptor',
   'response',
   'util',
   'connection',
   'control',
+  'directory',
   'exit_policy',
   'prereq',
   'process',
@@ -501,6 +513,7 @@ __all__ = [
   'UnsatisfiableRequest',
   'CircuitExtensionFailed',
   'DescriptorUnavailable',
+  'Timeout',
   'InvalidRequest',
   'InvalidArguments',
   'SocketError',
@@ -531,6 +544,9 @@ __all__ = [
   'TimeoutSetType',
 ]
 
+# Constant that we use by default for our User-Agent when downloading descriptors
+stem.USER_AGENT = 'Stem/%s' % __version__
+
 # Constant to indicate an undefined argument default. Usually we'd use None for
 # this, but users will commonly provide None as the argument so need something
 # else fairly unique...
@@ -538,6 +554,57 @@ __all__ = [
 UNDEFINED = '<Undefined_ >'
 
 
+class Endpoint(object):
+  """
+  Tor endpint that can be connected to.
+
+  .. versionadded:: 1.7.0
+
+  :var str address: ip address of the endpoint
+  :var int port: port of the endpoint
+  """
+
+  def __init__(self, address, port):
+    if not stem.util.connection.is_valid_ipv4_address(address) and not stem.util.connection.is_valid_ipv6_address(address):
+      raise ValueError("'%s' isn't a valid IPv4 or IPv6 address" % address)
+    elif not stem.util.connection.is_valid_port(port):
+      raise ValueError("'%s' isn't a valid port" % port)
+
+    self.address = address
+    self.port = int(port)
+
+  def __hash__(self):
+    return stem.util._hash_attr(self, 'address', 'port', cache = True)
+
+  def __eq__(self, other):
+    return hash(self) == hash(other) if isinstance(other, Endpoint) else False
+
+  def __ne__(self, other):
+    return not self == other
+
+
+class ORPort(Endpoint):
+  """
+  Tor relay's ORPort. The endpoint on which Tor accepts relay traffic.
+
+  :var list link_protocols: link protocol version we're willing to establish
+  """
+
+  def __init__(self, address, port, link_protocols = None):
+    super(ORPort, self).__init__(address, port)
+    self.link_protocols = link_protocols
+
+  def __hash__(self):
+    return stem.util._hash_attr(self, 'link_protocols', parent = Endpoint, cache = True)
+
+
+class DirPort(Endpoint):
+  """
+  Tor relay's DirPort. The endpoint on which Tor provides http access for
+  downloading descriptors.
+  """
+
+
 class ControllerError(Exception):
   'Base error for controller communication issues.'
 
@@ -579,15 +646,29 @@ class CircuitExtensionFailed(UnsatisfiableRequest):
     self.circ = circ
 
 
-class DescriptorUnavailable(OperationFailed):
+class DescriptorUnavailable(UnsatisfiableRequest):
   """
   Tor was unable to provide a descriptor for the given relay.
+
+  .. versionchanged:: 1.7.0
+     Subclassed under UnsatisfiableRequest rather than OperationFailed.
   """
 
   def __init__(self, message):
     super(DescriptorUnavailable, self).__init__(message = message)
 
 
+class Timeout(UnsatisfiableRequest):
+  """
+  Timeout requested by the caller was reached.
+
+  .. versionadded:: 1.7.0
+  """
+
+  def __init__(self, message):
+    super(Timeout, self).__init__(message = message)
+
+
 class InvalidRequest(OperationFailed):
   """
   Exception raised when the request was invalid or malformed.
@@ -862,3 +943,6 @@ HSAuth = stem.util.enum.UppercaseEnum(
   'STEALTH_AUTH',
   'UNKNOWN',
 )
+
+
+import stem.util.connection  # importing afterward to avoid circular dependency
