@@ -1,4 +1,4 @@
-# Copyright 2012-2017, Damian Johnson and The Tor Project
+# Copyright 2012-2018, Damian Johnson and The Tor Project
 # See LICENSE for licensing information
 
 """
@@ -61,10 +61,11 @@ import os
 import platform
 import re
 
+import stem.util
 import stem.util.proc
 import stem.util.system
 
-from stem.util import str_type, conf, enum, log
+from stem.util import conf, enum, log, str_tools
 
 # Connection resolution is risky to log about since it's highly likely to
 # contain sensitive information. That said, it's also difficult to get right in
@@ -407,7 +408,9 @@ def is_valid_ipv4_address(address):
   :returns: **True** if input is a valid IPv4 address, **False** otherwise
   """
 
-  if not isinstance(address, (bytes, str_type)):
+  if isinstance(address, bytes):
+    address = str_tools._to_unicode(address)
+  elif not stem.util._is_str(address):
     return False
 
   # checks if theres four period separated values
@@ -435,6 +438,11 @@ def is_valid_ipv6_address(address, allow_brackets = False):
   :returns: **True** if input is a valid IPv6 address, **False** otherwise
   """
 
+  if isinstance(address, bytes):
+    address = str_tools._to_unicode(address)
+  elif not stem.util._is_str(address):
+    return False
+
   if allow_brackets:
     if address.startswith('[') and address.endswith(']'):
       address = address[1:-1]
@@ -558,7 +566,7 @@ def address_to_int(address):
   # TODO: Could be neat to also use this for serialization if we also had an
   # int_to_address() function.
 
-  return int(_get_address_binary(address), 2)
+  return int(_address_to_binary(address), 2)
 
 
 def expand_ipv6_address(address):
@@ -597,7 +605,7 @@ def expand_ipv6_address(address):
     #
     #   '5.9.158.75' => '0509:9e4b'
 
-    ipv4_bin = _get_address_binary(address[ipv4_start:ipv4_end])
+    ipv4_bin = _address_to_binary(address[ipv4_start:ipv4_end])
     groupings = [ipv4_bin[16 * i:16 * (i + 1)] for i in range(2)]
     ipv6_snippet = ':'.join(['%04x' % int(group, 2) for group in groupings])
 
@@ -691,7 +699,7 @@ def _get_masked_bits(mask):
     raise ValueError("'%s' is an invalid subnet mask" % mask)
 
   # converts octets to binary representation
-  mask_bin = _get_address_binary(mask)
+  mask_bin = _address_to_binary(mask)
   mask_match = re.match('^(1*)(0*)$', mask_bin)
 
   if mask_match:
@@ -713,7 +721,7 @@ def _get_binary(value, bits):
   return ''.join([str((value >> y) & 1) for y in range(bits - 1, -1, -1)])
 
 
-def _get_address_binary(address):
+def _address_to_binary(address):
   """
   Provides the binary value for an IPv4 or IPv6 address.
 
