@@ -1,4 +1,4 @@
-# Copyright 2011-2017, Damian Johnson and The Tor Project
+# Copyright 2011-2018, Damian Johnson and The Tor Project
 # See LICENSE for licensing information
 
 """
@@ -40,7 +40,7 @@ constructed as simple type listings...
     +- __iter__ - iterator over our enum keys
 """
 
-from stem.util import str_type
+import stem.util
 
 
 def UppercaseEnum(*args):
@@ -76,7 +76,7 @@ class Enum(object):
     keys, values = [], []
 
     for entry in args:
-      if isinstance(entry, (bytes, str_type)):
+      if stem.util._is_str(entry):
         key, val = entry, _to_camel_case(entry)
       elif isinstance(entry, tuple) and len(entry) == 2:
         key, val = entry
